import {
  UserLayout,
  BasicLayout,
  BlankLayout,
  BigScreen,
  PageView
} from '@/layouts'
export default {
        path: '/salesManWarehouse',
        redirect: '/salesManagement/salesQueryNew',
        component: PageView,
        meta: {
          title: '销售管理',
          icon: 'account-book',
          permission: 'M_salesManagement'
        },
        children: [
          {
            path: '/salesManagement/salesQueryNew',
            redirect: '/salesManagement/salesQueryNew/list',
            name: 'salesQueryNew',
            component: BlankLayout,
            meta: {
              title: '销售单查询',
              icon: 'monitor',
              permission: 'M_salesQueryList'
            },
            hideChildrenInMenu: true,
            children: [
              {
                path: 'list',
                name: 'salesQueryNewList',
                component: () => import(/* webpackChunkName: "salesManagement" */ '@/views/salesManagement/salesQueryNew/list.vue'),
                meta: {
                  title: '销售单列表',
                  icon: 'monitor',
                  hidden: true,
                  permission: 'M_salesQueryList'
                }
              },
              {
                path: 'detail/:sn',
                name: 'salesNewDetail',
                component: () => import(/* webpackChunkName: "salesManagement" */ '@/views/salesManagement/salesQueryNew/detail.vue'),
                meta: {
                  title: '销售单详情',
                  icon: 'monitor',
                  hidden: true,
                  replaceTab: true,
                  permission: 'B_salesDetail'
                }
              },
              {
                path: 'detail/:sn',
                name: 'salesNewDetailAudit',
                component: () => import(/* webpackChunkName: "salesManagement" */ '@/views/salesManagement/salesQueryNew/detail.vue'),
                meta: {
                  title: '销售单审核',
                  icon: 'monitor',
                  hidden: true,
                  replaceTab: true,
                  permission: 'B_salesAudit'
                }
              },
              {
                path: 'add/:sn',
                name: 'salesNewAdd',
                component: () => import(/* webpackChunkName: "salesManagement" */ '@/views/salesManagement/salesQueryNew/edit.vue'),
                meta: {
                  title: '新增销售单',
                  icon: 'monitor',
                  hidden: true,
                  permission: 'B_salesEdit'
                }
              },
              {
                path: 'edit/:sn',
                name: 'salesNewEdit',
                component: () => import(/* webpackChunkName: "salesManagement" */ '@/views/salesManagement/salesQueryNew/edit.vue'),
                meta: {
                  title: '编辑销售单',
                  icon: 'monitor',
                  hidden: true,
                  permission: 'B_salesEdit'
                }
              },
              {
                path: 'waitDispatch/:salesBillSn',
                name: 'waitDispatchNew',
                component: () => import(/* webpackChunkName: "salesManagement" */ '@/views/salesManagement/waitDispatchNew/edit.vue'),
                meta: {
                  title: '下推销售单',
                  icon: 'monitor',
                  replaceTab: true,
                  hidden: true,
                  permission: 'B_salesDispatch'
                }
              },
              {
                path: 'waitCostOrder',
                name: 'waitCostOrder',
                component: () => import(/* webpackChunkName: "salesManagement" */ '@/views/salesManagement/waitCostOrder/list.vue'),
                meta: {
                  title: '待转费用报销单',
                  icon: 'monitor',
                  hidden: true,
                  permission: 'B_salesDispatch'
                }
              }
            ]
          },
          {
            path: '/salesManagement/salesOrderWarehouse',
            redirect: '/salesManagement/salesOrderWarehouse/list',
            name: 'salesOrderWarehouse',
            component: BlankLayout,
            meta: {
              title: '仓库销售单',
              icon: 'vertical-align-bottom',
              permission: 'M_salesOrderWarehouseList'
            },
            hideChildrenInMenu: true,
            children: [
              {
                path: 'list',
                name: 'salesOrderWarehouseList',
                component: () => import(/* webpackChunkName: "salesManagement" */ '@/views/salesManagement/salesOrderWarehouse/list.vue'),
                meta: {
                  title: '仓库销售单列表',
                  icon: 'vertical-align-bottom',
                  hidden: true,
                  permission: 'M_salesOrderWarehouseList'
                }
              },
              {
                path: 'detail/:sn/:wsn',
                name: 'saleOrderDetail',
                component: () => import(/* webpackChunkName: "salesManagement" */ '@/views/salesManagement/salesOrderWarehouse/detail.vue'),
                meta: {
                  title: '仓库销售单列表详情',
                  icon: 'vertical-align-bottom',
                  replaceTab: true,
                  hidden: true,
                  permission: 'B_salesOrderWarehouseDetail'
                }
              }
            ]
          },
          {
            path: '/salesManagement/pushOrderManagement',
            redirect: '/salesManagement/pushOrderManagement/list',
            name: 'pushOrderManagement',
            component: BlankLayout,
            meta: {
              title: '下推订单列表',
              icon: 'vertical-align-bottom',
              permission: 'M_pushOrderManagementList'
            },
            hideChildrenInMenu: true,
            children: [
              {
                path: 'list',
                name: 'pushOrderManagementList',
                component: () => import(/* webpackChunkName: "salesManagement" */ '@/views/salesManagement/pushOrderManagement/list.vue'),
                meta: {
                  title: '下推订单列表',
                  icon: 'vertical-align-bottom',
                  hidden: true,
                  permission: 'M_pushOrderManagementList'
                }
              },
              {
                path: 'detail/:sn/:type',
                name: 'pushOrderDetail',
                component: () => import(/* webpackChunkName: "salesManagement" */ '@/views/salesManagement/pushOrderManagement/detail.vue'),
                meta: {
                  title: '下推订单详情',
                  icon: 'vertical-align-bottom',
                  replaceTab: true,
                  hidden: true,
                  permission: 'B_dispatchDetail'
                }
              }
            ]
          },
          {
            path: '/salesManagement/salesCollection',
            redirect: '/salesManagement/salesCollection/list',
            name: 'salesCollection',
            component: BlankLayout,
            meta: {
              title: '销售收款',
              icon: 'vertical-align-bottom',
              permission: 'M_salesCollectionList'
            },
            hideChildrenInMenu: true,
            children: [
              {
                path: 'list',
                name: 'salesCollectionList',
                component: () => import(/* webpackChunkName: "salesManagement" */ '@/views/salesManagement/salesCollection/list.vue'),
                meta: {
                  title: '销售收款',
                  icon: 'vertical-align-bottom',
                  hidden: true,
                  permission: 'M_salesCollectionList'
                }
              }
            ]
          },
          {
            path: '/salesManagement/stockPrint',
            redirect: '/salesManagement/stockPrint/list',
            name: 'stockPrint',
            component: BlankLayout,
            meta: {
              title: '备货打印',
              icon: 'vertical-align-bottom',
              permission: 'M_stockPrintList'
            },
            hideChildrenInMenu: true,
            children: [
              {
                path: 'list',
                name: 'stockPrintList',
                component: () => import(/* webpackChunkName: "salesManagement" */ '@/views/salesManagement/stockPrint/list.vue'),
                meta: {
                  title: '备货打印',
                  icon: 'vertical-align-bottom',
                  hidden: true,
                  permission: 'M_stockPrintList'
                }
              }
            ]
          },
          {
            path: '/salesManagement/receiptPrint',
            redirect: '/salesManagement/receiptPrint/list',
            name: 'receiptPrint',
            component: BlankLayout,
            meta: {
              title: '收款打印',
              icon: 'vertical-align-bottom',
              permission: 'M_receiptPrintList'
            },
            hideChildrenInMenu: true,
            children: [
              {
                path: 'list',
                name: 'receiptPrintList',
                component: () => import(/* webpackChunkName: "salesManagement" */ '@/views/salesManagement/receiptPrint/list.vue'),
                meta: {
                  title: '收款打印',
                  icon: 'vertical-align-bottom',
                  hidden: true,
                  permission: 'M_receiptPrintList'
                }
              }
            ]
          },
          {
            path: '/salesManagement/matchSendOutOrder',
            redirect: '/salesManagement/matchSendOutOrder/list',
            name: 'matchSendOutOrder',
            component: BlankLayout,
            meta: {
              title: '发货对单',
              icon: 'vertical-align-bottom',
              permission: 'M_matchSendOutOrderList'
            },
            hideChildrenInMenu: true,
            children: [
              {
                path: 'list',
                name: 'matchSendOutOrderList',
                component: () => import(/* webpackChunkName: "salesManagement" */ '@/views/salesManagement/matchSendOutOrder/list.vue'),
                meta: {
                  title: '发货对单',
                  icon: 'vertical-align-bottom',
                  hidden: true,
                  permission: 'M_matchSendOutOrderList'
                }
              }
            ]
          },
          {
            path: '/salesManagement/examineVerify',
            redirect: '/salesManagement/examineVerify/list',
            name: 'examineVerify',
            component: BlankLayout,
            meta: {
              title: '备货审核',
              icon: 'audit',
              permission: 'M_examineVerifyList'
            },
            hideChildrenInMenu: true,
            children: [
              {
                path: 'list',
                name: 'examineVerifyList',
                component: () => import(/* webpackChunkName: "salesManagement" */ '@/views/salesManagement/examineVerify/list.vue'),
                meta: {
                  title: '备货审核列表',
                  icon: 'audit',
                  hidden: true,
                  permission: 'M_examineVerifyList'
                }
              }
            ]
          },
          {
            path: '/salesManagement/outboundOrder',
            redirect: '/salesManagement/outboundOrder/list',
            name: 'outboundOrder',
            component: BlankLayout,
            meta: {
              title: '出库',
              icon: 'export',
              permission: 'M_outboundOrderList'
            },
            hideChildrenInMenu: true,
            children: [
              {
                path: 'list',
                name: 'outboundOrderList',
                component: () => import(/* webpackChunkName: "salesManagement" */ '@/views/salesManagement/outboundOrder/list.vue'),
                meta: {
                  title: '出库列表',
                  icon: 'export',
                  hidden: true,
                  permission: 'M_outboundOrderList'
                }
              }
            ]
          },
          {
            path: '/salesManagement/sendOutOrder',
            redirect: '/salesManagement/sendOutOrder/list',
            name: 'sendOutOrder',
            component: BlankLayout,
            meta: {
              title: '发货单列表',
              icon: 'export',
              permission: 'M_sendOutOrderList'
            },
            hideChildrenInMenu: true,
            children: [
              {
                path: 'list',
                name: 'sendOutOrderList',
                component: () => import(/* webpackChunkName: "salesManagement" */ '@/views/salesManagement/sendOutOrder/list.vue'),
                meta: {
                  title: '发货单列表',
                  icon: 'export',
                  hidden: true,
                  permission: 'M_sendOutOrderList'
                }
              }
            ]
          },
          {
            path: '/salesManagement/backorder',
            redirect: '/salesManagement/backorder/list',
            name: 'backorder',
            component: BlankLayout,
            meta: {
              title: '销售缺货列表',
              icon: 'exception',
              permission: 'M_backorderList'
            },
            hideChildrenInMenu: true,
            children: [
              {
                path: 'list',
                name: 'backorderList',
                component: () => import(/* webpackChunkName: "salesManagement" */ '@/views/salesManagement/backorder/list.vue'),
                meta: {
                  title: '销售缺货列表',
                  icon: 'exception',
                  hidden: true,
                  permission: 'M_backorderList'
                }
              }
            ]
          },
          {
            path: '/salesManagement/shortageStatisticsC',
            redirect: '/salesManagement/shortageStatisticsC/list',
            name: 'shortageStatisticsC',
            component: BlankLayout,
            meta: {
              title: '缺货统计（按客户）',
              icon: 'file-done',
              permission: 'M_shortageStatisticsCList'
            },
            hideChildrenInMenu: true,
            children: [
              {
                path: 'list',
                name: 'shortageStatisticsCList',
                component: () => import(/* webpackChunkName: "salesManagement" */ '@/views/salesManagement/shortageStatisticsC/list.vue'),
                meta: {
                  title: '缺货统计（按客户）',
                  icon: 'file-done',
                  hidden: true,
                  permission: 'M_shortageStatisticsCList'
                }
              }
            ]
          },
          {
            path: '/salesManagement/shortageStatisticsP',
            redirect: '/salesManagement/shortageStatisticsP/list',
            name: 'shortageStatisticsP',
            component: BlankLayout,
            meta: {
              title: '缺货统计（按产品）',
              icon: 'file-protect',
              permission: 'M_shortageStatisticsPList'
            },
            hideChildrenInMenu: true,
            children: [
              {
                path: 'list',
                name: 'shortageStatisticsPList',
                component: () => import(/* webpackChunkName: "salesManagement" */ '@/views/salesManagement/shortageStatisticsP/list.vue'),
                meta: {
                  title: '缺货统计（按产品）',
                  icon: 'file-protect',
                  hidden: true,
                  permission: 'M_shortageStatisticsPList'
                }
              }
            ]
          },
          {
            path: '/salesManagement/priceInquiry',
            redirect: '/salesManagement/priceInquiry/list',
            name: 'priceInquiry',
            component: BlankLayout,
            meta: {
              title: '价格查询',
              icon: 'file-protect',
              permission: 'M_priceInquiryList'
            },
            hideChildrenInMenu: true,
            children: [
              {
                path: 'list',
                name: 'priceInquiryList',
                component: () => import(/* webpackChunkName: "salesManagement" */ '@/views/salesManagement/priceInquiry/list.vue'),
                meta: {
                  title: '价格查询列表',
                  icon: 'file-protect',
                  hidden: true,
                  permission: 'M_priceInquiryList'
                }
              }
            ]
          },
          {
            path: '/salesManagement/salesList',
            redirect: '/salesManagement/salesList/list',
            name: 'salesList',
            component: BlankLayout,
            meta: {
              title: '销售一览表',
              icon: 'file-protect',
              permission: 'M_salesList'
            },
            hideChildrenInMenu: true,
            children: [
              {
                path: 'list',
                name: 'salesMainList',
                component: () => import(/* webpackChunkName: "salesManagement" */ '@/views/salesManagement/salesList/list.vue'),
                meta: {
                  title: '销售一览表',
                  icon: 'file-protect',
                  hidden: true,
                  permission: 'M_salesList'
                }
              }
            ]
          }
        ]
      }